==> qmltube_0.3.1.tar.gz: qmltube-0.3.1/downloadmanager.h <==
#ifndef DOWNLOADMANAGER_H
#define DOWNLOADMANAGER_H

#include <QObject>
#include <QtNetwork/QNetworkAccessManager>
#include <QUrl>
#include <QFile>
#include <QDir>
#include <QList>

class QNetworkAccessManager;
class QNetworkReply;
class QNetworkRequest;

class DownloadManager : public QObject {
    Q_OBJECT

    Q_PROPERTY(bool isDownloading
               READ isDownloading
               NOTIFY downloadingChanged)

public:
    explicit DownloadManager(QObject *parent = 0);

    void setNetworkAccessManager(QNetworkAccessManager *manager);
    bool isDownloading() const { return downloading; }

signals:

public slots:
    void setDownloadQuality(const QString &quality);
    void startDownload(const QString &filePath, const QString &url);
    void pauseDownload();
    void cancelDownload();

private slots:
    void parseVideoPage();
    void getVideoUrl(const QString &playerUrl);
    void performDownload(const QByteArray &videoUrl);
    void downloadFinished();
    void downloadReadyRead();

private:
    QNetworkAccessManager *nam;
    int downloadFormat;
    QHash<QString, int> dlMap;
    QFile output;
    QNetworkReply *downloadReply;
    bool downloading;

signals:
    void alert(const QString &message);
    void gotVideoUrl(const QByteArray &videoUrl);
    void videoUrlError();
    void downloadCompleted();
    void downloadCancelled();
    void statusChanged(const QString &status);
    void progressChanged(qint64 bytesReceived, qint64 bytesTotal);
    void qualityChanged(const QString quality);
    void downloadingChanged();
};

#endif // DOWNLOADMANAGER_H

==> qmltube_0.3.8.tar.gz: qmltube-0.3.8/downloadmanager.h <==
#ifndef DOWNLOADMANAGER_H
#define DOWNLOADMANAGER_H

#include <QObject>
#include <QtNetwork/QNetworkAccessManager>
#include <QUrl>
#include <QFile>
#include <QDir>
#include <QList>

class QNetworkAccessManager;
class QNetworkReply;
class QNetworkRequest;

class DownloadManager : public QObject {
    Q_OBJECT

    Q_PROPERTY(bool isDownloading
               READ isDownloading
               NOTIFY downloadingChanged)

public:
    explicit DownloadManager(QObject *parent = 0);

    void setNetworkAccessManager(QNetworkAccessManager *manager);
    bool isDownloading() const { return downloading; }

signals:

public slots:
    void setDownloadQuality(const QString &quality);
    void startDownload(const QString &filePath, const QString &url);
    void pauseDownload();
    void cancelDownload();

private slots:
    void parseVideoPage();
    void getVideoUrl(const QString &playerUrl);
    void performDownload(const QByteArray &videoUrl);
    void downloadFinished();
    void downloadReadyRead();

private:
    QNetworkAccessManager *nam;
    int downloadFormat;
    QHash<QString, int> dlMap;
    QFile output;
    QNetworkReply *downloadReply;
    bool downloading;

signals:
    void alert(const QString &message);
    void gotVideoUrl(const QByteArray &videoUrl);
    void videoUrlError();
    void downloadCompleted(const QString &filename);
    void downloadCancelled();
    void statusChanged(const QString &status);
    void progressChanged(qint64 bytesReceived, qint64 bytesTotal);
    void qualityChanged(const QString quality);
    void downloadingChanged();
};

#endif // DOWNLOADMANAGER_H
